summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/kernel/tqaccel.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/kernel/tqaccel.cpp')
-rw-r--r--tqtinterface/qt4/src/kernel/tqaccel.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/tqtinterface/qt4/src/kernel/tqaccel.cpp b/tqtinterface/qt4/src/kernel/tqaccel.cpp
index fd47345..96a3470 100644
--- a/tqtinterface/qt4/src/kernel/tqaccel.cpp
+++ b/tqtinterface/qt4/src/kernel/tqaccel.cpp
@@ -82,7 +82,7 @@ using namespace Qt;
Example:
\snippet doc/src/snippets/code/src_qt3support_other_q3accel.cpp 0
- A TQAccel tqcontains a list of accelerator items that can be
+ A TQAccel contains a list of accelerator items that can be
manipulated using insertItem(), removeItem(), clear(), key() and
findKey().
@@ -915,7 +915,7 @@ QString TQAccel::keyToString(QKeySequence k)
if \a s is not recognized.
This function is typically used with \link TQT_BASE_OBJECT_NAME::tr() tr
- \endlink(), so that accelerator keys can be tqreplaced in
+ \endlink(), so that accelerator keys can be replaced in
translations:
\snippet doc/src/snippets/code/src_qt3support_other_q3accel.cpp 5
@@ -1065,9 +1065,9 @@ QT_END_NAMESPACE
fileMenu->insertItem( "Undo", tqparent, TQT_SLOT(undo()), CTRL+Key_Z );
\endcode
- A TQAccel tqcontains a list of accelerator items that can be
+ A TQAccel contains a list of accelerator items that can be
manipulated using insertItem(), removeItem(), clear(), key() and
- tqfindKey().
+ findKey().
Each accelerator item consists of an identifier and a \l
TQKeySequence. A single key sequence consists of a keyboard code
@@ -1536,7 +1536,7 @@ TQAccelPrivate::~TQAccelPrivate()
TQAccelManager::self()->unregisterAccel( this );
}
-static TQAccelItem *tqfind_id( TQAccelList &list, int id )
+static TQAccelItem *find_id( TQAccelList &list, int id )
{
register TQAccelItem *item = list.first();
while ( item && item->id != id )
@@ -1544,7 +1544,7 @@ static TQAccelItem *tqfind_id( TQAccelList &list, int id )
return item;
}
-static TQAccelItem *tqfind_key( TQAccelList &list, const TQKeySequence &key )
+static TQAccelItem *find_key( TQAccelList &list, const TQKeySequence &key )
{
register TQAccelItem *item = list.first();
while ( item && !( item->key == key ) )
@@ -1676,7 +1676,7 @@ uint TQAccel::count() const
static int get_seq_id()
{
- static int seq_no = -2; // -1 is used as return value in tqfindKey()
+ static int seq_no = -2; // -1 is used as return value in findKey()
return seq_no--;
}
@@ -1713,7 +1713,7 @@ int TQAccel::insertItem( const TQKeySequence& key, int id )
void TQAccel::removeItem( int id )
{
- if ( tqfind_id( d->aitems, id) )
+ if ( find_id( d->aitems, id) )
d->aitems.remove();
}
@@ -1735,7 +1735,7 @@ void TQAccel::clear()
TQKeySequence TQAccel::key( int id )
{
- TQAccelItem *item = tqfind_id( d->aitems, id);
+ TQAccelItem *item = find_id( d->aitems, id);
return item ? item->key : TQKeySequence( 0 );
}
@@ -1745,9 +1745,9 @@ TQKeySequence TQAccel::key( int id )
\a key, or -1 if the item cannot be found.
*/
-int TQAccel::tqfindKey( const TQKeySequence& key ) const
+int TQAccel::findKey( const TQKeySequence& key ) const
{
- TQAccelItem *item = tqfind_key( d->aitems, key );
+ TQAccelItem *item = find_key( d->aitems, key );
return item ? item->id : -1;
}
@@ -1761,7 +1761,7 @@ int TQAccel::tqfindKey( const TQKeySequence& key ) const
bool TQAccel::isItemEnabled( int id ) const
{
- TQAccelItem *item = tqfind_id( d->aitems, id);
+ TQAccelItem *item = find_id( d->aitems, id);
return item ? item->enabled : FALSE;
}
@@ -1777,7 +1777,7 @@ bool TQAccel::isItemEnabled( int id ) const
void TQAccel::setItemEnabled( int id, bool enable )
{
- TQAccelItem *item = tqfind_id( d->aitems, id);
+ TQAccelItem *item = find_id( d->aitems, id);
if ( item )
item->enabled = enable;
}
@@ -1805,7 +1805,7 @@ void TQAccel::setItemEnabled( int id, bool enable )
bool TQAccel::connectItem( int id, const TQT_BASE_OBJECT_NAME *receiver, const char *member )
{
- TQAccelItem *item = tqfind_id( d->aitems, id);
+ TQAccelItem *item = find_id( d->aitems, id);
if ( item ) {
if ( !item->signal ) {
item->signal = new TQSignal;
@@ -1826,7 +1826,7 @@ bool TQAccel::connectItem( int id, const TQT_BASE_OBJECT_NAME *receiver, const c
bool TQAccel::disconnectItem( int id, const TQT_BASE_OBJECT_NAME *receiver,
const char *member )
{
- TQAccelItem *item = tqfind_id( d->aitems, id);
+ TQAccelItem *item = find_id( d->aitems, id);
if ( item && item->signal )
return item->signal->disconnect( receiver, member );
return FALSE;
@@ -1877,7 +1877,7 @@ TQKeySequence TQAccel::shortcutKey( const TQString &str )
int p = 0;
while ( p >= 0 ) {
- p = str.tqfind( '&', p ) + 1;
+ p = str.find( '&', p ) + 1;
if ( p <= 0 || p >= (int)str.length() )
return 0;
if ( str[p] != '&' ) {
@@ -1919,7 +1919,7 @@ TQString TQAccel::keyToString( TQKeySequence k )
if \a s is not recognized.
This function is typically used with \link TQObject::tr() tr
- \endlink(), so that accelerator keys can be tqreplaced in
+ \endlink(), so that accelerator keys can be replaced in
translations:
\code
@@ -1960,7 +1960,7 @@ TQKeySequence TQAccel::stringToKey( const TQString & s )
void TQAccel::setWhatsThis( int id, const TQString& text )
{
- TQAccelItem *item = tqfind_id( d->aitems, id);
+ TQAccelItem *item = find_id( d->aitems, id);
if ( item )
item->whatsthis = text;
}
@@ -1974,7 +1974,7 @@ void TQAccel::setWhatsThis( int id, const TQString& text )
TQString TQAccel::whatsThis( int id ) const
{
- TQAccelItem *item = tqfind_id( d->aitems, id);
+ TQAccelItem *item = find_id( d->aitems, id);
return item? item->whatsthis : TQString::null;
}
@@ -2083,7 +2083,7 @@ documentation for details.
The \link http://www.amazon.com/exec/obidos/ASIN/0735605661/trolltech/t
Microsoft book \endlink has ISBN 0735605661. The corresponding Open Group
-book is very hard to tqfind, rather expensive and we cannot recommend
+book is very hard to find, rather expensive and we cannot recommend
it. However, if you really want it, OGPubs@opengroup.org might be able
to help. Ask them for ISBN 1859121047.